@@ -19,6 +19,10 @@ import google.resumable_media.requests
 from mod9.reformat import config
 
 
+class Mod9UnexpectedEngineResponseError(Exception):
+    pass
+
+
 class PropagatingThread(threading.Thread):
     """
     Thread class that propagates any exception that occurred during
@@ -72,25 +76,28 @@ def parse_wav_encoding(audio_settings):
     """
 
     if audio_settings is None:
-        return False
+        return False, 0
     elif isinstance(audio_settings, TeeGeneratorType):
         audio_settings_header = next(audio_settings)
         if audio_settings_header[:4] == b'RIFF' and audio_settings_header[8:12] == b'WAVE':
-            # Return the encoding type, which is always truthy.
+            # Get the encoding type, which is always truthy.
             encoding_bytes = audio_settings_header[20:22]
             if encoding_bytes == b'\x01\x00':
-                return 'pcm_s16le'
+                wav_encoding = 'pcm_s16le'
             elif encoding_bytes == b'\x06\x00':
-                return 'a-law'
+                wav_encoding = 'a-law'
             elif encoding_bytes == b'\x07\x00':
-                return 'mu-law'
+                wav_encoding = 'mu-law'
             else:
-                return True
+                wav_encoding = True
+            # Get the sample rate.
+            sample_rate = int.from_bytes(audio_settings_header[24:28], byteorder='little')
+            return wav_encoding, sample_rate
         else:
-            return False
+            return False, 0
     elif isinstance(audio_settings, str):
         # Will fail in the pathological case of a non-WAV file stored with a ``.wav`` suffix.
-        return audio_settings.endswith('.wav')
+        return audio_settings.endswith('.wav'), 0
     else:
         raise TypeError('Expected type None or TeeGeneratorType or str.')
 
@@ -421,3 +428,61 @@ def get_transcripts_mod9(options, audio_input):
             yield json.loads(line)
 
         producer_thread.join()
+
+
+def get_loaded_models_mod9():
+    """
+    Query Engine for a list of models and return loaded models.
+
+    Args:
+        None
+
+    Returns:
+        dict[str, dict[str, Union[bool, dict, int, str]]]:
+            Metadata about models currently loaded in Engine.
+    """
+
+    with socket.create_connection(
+        (config.MOD9_ASR_ENGINE_HOST, config.MOD9_ASR_ENGINE_PORT),
+        timeout=config.SOCKET_CONNECTION_TIMEOUT_SECONDS,
+    ) as sock:
+        sock.settimeout(config.SOCKET_INACTIVITY_TIMEOUT_SECONDS)
+
+        # Start by sending request to list models (terminated w/ newline character).
+        get_model_request = '{"command": "get-models-info"}\n'
+        sock.sendall(get_model_request.encode())
+
+        sockfile = sock.makefile(mode='r')
+
+        get_models_response = json.loads(sockfile.readline())
+        if get_models_response.get('status') != 'completed':
+            raise KeyError(
+                f"Got response '{get_models_response}'; must have `.status` field `completed`."
+            )
+        if 'models' not in get_models_response:
+            raise Mod9UnexpectedEngineResponseError(
+                f"Got response '{get_models_response}'; must have `.models` field."
+            )
+
+        sockfile.close()
+
+        return get_models_response['models']
+
+
+def find_loaded_models_with_rate(rate):
+    """
+    Get all models loaded in Engine that have the specified rate.
+
+    Args:
+        rate (int):
+            Check for loaded Engine models with this rate.
+
+    Returns:
+        list[dict[str, Union[bool, dict, int, str]]]:
+            Metadata about models currently loaded in Engine with specified rate (or empty list).
+    """
+    try:
+        models = get_loaded_models_mod9()
+    except Mod9UnexpectedEngineResponseError:
+        return []
+    return [model for model in models if model['rate'] == rate]
