@@ -1,5 +1,10 @@
 #!/usr/bin/env python3
 
+"""
+REST API wrapper over the Mod9 ASR Engine TCP Server.
+"""
+
+import argparse
 from collections import OrderedDict
 from datetime import datetime
 import json
@@ -18,7 +23,18 @@ from mod9.reformat.utils import get_transcripts_mod9
 from mod9.reformat import google as reformat
 
 app = Flask(__name__)
+# Make JSON output readable.
+#  ``RESTFUL_JSON`` is a config var from ``flask_restful`` that
+#  allows JSON formatting similar to ``json.dumps()``, see docs:
+#  https://flask-restful.readthedocs.io/en/latest/extending.html#:~:text=RESTFUL_JSON
 app.config['RESTFUL_JSON'] = {'indent': 2, 'sort_keys': False}
+if config.FLASK_ENV is not None:
+    app.config['ENV'] = config.FLASK_ENV
+else:
+    # Stop output of warning message on server start.
+    #  Note this is not recommended by Flask devs, but should be fine for our purposes:
+    #  https://flask.palletsprojects.com/en/1.1.x/config/#environment-and-debug-features
+    app.config['ENV'] = 'development'
 api = Api(app)
 
 # Input parser for Recognize and LongRunningRecognize resources.
@@ -44,14 +60,23 @@ operation_results = {}
 
 
 def test_host_port():
-    """Check if Mod9 ASR Engine is online. Loop until get server_ready response. Print stats."""
+    """
+    Check if Mod9 ASR Engine is online. Loop until get ``server_ready``
+    response. Log stats.
+
+    Args:
+        None
+
+    Returns:
+        None
+    """
 
     logging.info(
         "Checking for Mod9 ASR Engine running at %s:%s...",
         config.MOD9_ASR_ENGINE_HOST, config.MOD9_ASR_ENGINE_PORT
     )
 
-    # Loop sending get-stats until receive `server_ready is True` response.
+    # Loop sending get-stats until receive ``server_ready is True`` response.
     response = dict()
     while response.get('server_ready') is not True:
         with socket.create_connection(
@@ -64,7 +89,7 @@ def test_host_port():
             with sock.makefile(mode='r') as sockfile:
                 response = json.loads(sockfile.readline())
 
-        # Output and sleep except when receive `server_ready is True` response.
+        # Output and sleep except when receive ``server_ready is True`` response.
         if response['server_ready'] is not True:
             logging.error(
                 "The Engine is not ready yet. Will attempt to connect again in %s seconds...",
@@ -78,19 +103,30 @@ def test_host_port():
     )
 
 
-def send_requests(sock, requests):
-    """Send requests to server."""
-
-    for request in requests:
-        sock.sendall(request)
-
-
 def place_reformatted_mod9_response_in_operation_results(
     mod9_config_settings,
     mod9_audio_settings,
     operation_name,
 ):
-    """Get and format response from Mod9 ASR Engine. Place response in proper operation_result."""
+    """
+    Get and format response from Mod9 ASR Engine. Place response in
+    proper ``operation_result``.
+
+    Args:
+        mod9_config_settings (dict[str, Union[dict, float, int, str]]):
+            Mod9-style transcription options.
+        mod9_audio_settings (Union[
+                GeneratorType,
+                TeeGeneratorType,
+                str,
+        ]):
+            Audio content to be transcribed.
+        operation_name (str):
+            Transcription operation UUID.
+
+    Returns:
+        None
+    """
 
     # Response type metadata constant string.
     response_type = 'type.googleapis.com/google.cloud.speech.v1p1beta1.LongRunningRecognizeResponse'
@@ -124,9 +160,10 @@ def place_reformatted_mod9_response_in_operation_results(
 
 
 class Recognize(Resource):
-    """Implement synchronous speech-to-text."""
+    """Implement synchronous ASR for ``/recognize`` endpoint."""
 
     def post(self):
+        """Perform synchronous ASR on POSTed config and audio."""
         # Translate request -> Mod9 format.
         args = parser.parse_args()
         try:
@@ -155,29 +192,33 @@ class Recognize(Resource):
 
 
 class Operations(Resource):
-    """Implement operations name fetching for /operations endpoint."""
-
-    def __init__(self):
-        pass
+    """
+    Implement operations name fetching for ``/operations`` endpoint.
+    """
 
     def get(self):
+        """Output finished and presently running operation names."""
         return {'operations': list(reversed(operation_names))}
 
 
 class GetOperationByName(Resource):
-    """Implement operation result fetching for /operations/<operation_name> endpoint."""
-
-    def __init__(self):
-        pass
+    """
+    Implement operation result fetching for
+    ``/operations/<operation_name>`` endpoint.
+    """
 
     def get(self, operation_name):
+        """Output operation with given operation name."""
         return operation_results[str(operation_name)]
 
 
 class LongRunningRecognize(Resource):
-    """Implement long-running speech-to-text for /longrunningrecognize endpoint."""
+    """
+    Implement asynchronous ASR for ``/longrunningrecognize`` endpoint.
+    """
 
     def post(self):
+        """Perform asynchronous ASR on POSTed config and audio."""
         # Translate request -> Mod9 format.
         args = parser.parse_args()
         try:
@@ -245,7 +286,29 @@ api.add_resource(
 
 
 def main():
+    parser = argparse.ArgumentParser()
+    parser.add_argument(
+        '--host',
+        help='Mod9 ASR Engine TCP Server host name.'
+             ' Overrides environmental variable `MOD9_ASR_ENGINE_HOST`.',
+    )
+    parser.add_argument(
+        '--port',
+        help='Mod9 ASR Engine TCP Server port.'
+             ' Overrides environmental variable `MOD9_ASR_ENGINE_PORT`.',
+        type=int,
+    )
+    args = parser.parse_args()
+
     logging.basicConfig(format="%(levelname)s: %(message)s", level=logging.INFO)
+
+    if args.host is not None:
+        logging.info("Setting host to '%s' from command line argument.", args.host)
+        config.MOD9_ASR_ENGINE_HOST = args.host
+    if args.port is not None:
+        logging.info("Setting port to '%s' from command line argument.", args.port)
+        config.MOD9_ASR_ENGINE_PORT = args.port
+
     test_host_port()
     app.run(debug=False)
 
